// Fetch the data from the URL
const dataURL =
  'https://gist.githubusercontent.com/Mahesh-Polisetty/e98d8e7ab4a82a70e0a973207cd2d903/raw/0614b4f1d8703afd3e663d804a4c635ff616f47c/gistfile1.txt';

// Preprocess the data for the tree graph
d3.csv(dataURL)
  .then((data) => {
    // Preprocess data for the tree structure
    const treeData = processDataForTree(data);

    // Create visualization using treeData
    createTreeVisualization(treeData);
  })
  .catch((error) => {
    console.error('Error loading data:', error);
  });

// Function to preprocess data for tree structure
function processDataForTree(data) {
  const rootData = data.find(
    (d) => d['Dist Code'] === 'India',
  ); // Assuming 'India' is the root node
  const treeData = {
    name: rootData['Dist Name'],
    children: [
      {
        name: 'Rice',
        value: parseFloat(rootData['RICE AREA (1000 ha)']),
      },
      {
        name: 'Wheat',
        value: parseFloat(rootData['WHEAT AREA (1000 ha)']),
      },
      // Add other children nodes as needed
    ],
  };
  return treeData;
}

// Function to create a tree structure visualization
function createTreeVisualization(treeData) {
  const svg = d3.select('#tree-svg');
  const width = +svg.attr('width');
  const height = +svg.attr('height');
  const margin = {
    top: 20,
    right: 160,
    bottom: 50,
    left: 140,
  };

  const treeLayout = d3
    .tree()
    .size([
      height - margin.top - margin.bottom,
      width - margin.left - margin.right,
    ]);

  const root = d3.hierarchy(treeData);
  treeLayout(root);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  g.selectAll('.link')
    .data(root.links())
    .enter()
    .append('path')
    .attr('class', 'link')
    .attr(
      'd',
      d3
        .linkHorizontal()
        .x((d) => d.y)
        .y((d) => d.x),
    );

  const node = g
    .selectAll('.node')
    .data(root.descendants())
    .enter()
    .append('g')
    .attr('class', 'node')
    .attr('transform', (d) => `translate(${d.y},${d.x})`);

  node
    .append('circle')
    .attr('r', 4)
    .attr('fill', (d) =>
      d.children ? 'black' : 'steelblue',
    );

  node
    .append('text')
    .attr('dy', '.35em')
    .attr('x', (d) => (d.children ? -13 : 13))
    .style('text-anchor', (d) =>
      d.children ? 'end' : 'start',
    )
    .text((d) => d.data.name)
    .clone(true)
    .lower()
    .attr('stroke', 'white');
}
